==> zio-aws-ec2_2.12-7.21.15.11-sources.jar: zio/aws/ec2/model/ClientVpnConnectionStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ClientVpnConnectionStatus(
    code: Optional[zio.aws.ec2.model.ClientVpnConnectionStatusCode] =
      Optional.Absent,
    message: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus = {
    import ClientVpnConnectionStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ClientVpnConnectionStatus.ReadOnly =
    zio.aws.ec2.model.ClientVpnConnectionStatus.wrap(buildAwsValue())
}
object ClientVpnConnectionStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientVpnConnectionStatus =
      zio.aws.ec2.model.ClientVpnConnectionStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Optional[zio.aws.ec2.model.ClientVpnConnectionStatusCode]
    def message: Optional[String]
    def getCode
        : ZIO[Any, AwsError, zio.aws.ec2.model.ClientVpnConnectionStatusCode] =
      AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
  ) extends zio.aws.ec2.model.ClientVpnConnectionStatus.ReadOnly {
    override val code
        : Optional[zio.aws.ec2.model.ClientVpnConnectionStatusCode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.code())
        .map(value =>
          zio.aws.ec2.model.ClientVpnConnectionStatusCode.wrap(value)
        )
    override val message: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.message())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
  ): zio.aws.ec2.model.ClientVpnConnectionStatus.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.127.2-sources.jar: zio/aws/ec2/model/ClientVpnConnectionStatus.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ClientVpnConnectionStatus(
    code: Option[zio.aws.ec2.model.ClientVpnConnectionStatusCode] = None,
    message: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus = {
    import ClientVpnConnectionStatus.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
      .builder()
      .optionallyWith(code.map(value => value.unwrap))(_.code)
      .optionallyWith(message.map(value => value: java.lang.String))(_.message)
      .build()
  }
  def asReadOnly: zio.aws.ec2.model.ClientVpnConnectionStatus.ReadOnly =
    zio.aws.ec2.model.ClientVpnConnectionStatus.wrap(buildAwsValue())
}
object ClientVpnConnectionStatus {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.ClientVpnConnectionStatus =
      zio.aws.ec2.model.ClientVpnConnectionStatus(
        code.map(value => value),
        message.map(value => value)
      )
    def code: Option[zio.aws.ec2.model.ClientVpnConnectionStatusCode]
    def message: Option[String]
    def getCode
        : ZIO[Any, AwsError, zio.aws.ec2.model.ClientVpnConnectionStatusCode] =
      AwsError.unwrapOptionField("code", code)
    def getMessage: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("message", message)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
  ) extends zio.aws.ec2.model.ClientVpnConnectionStatus.ReadOnly {
    override val code: Option[zio.aws.ec2.model.ClientVpnConnectionStatusCode] =
      scala
        .Option(impl.code())
        .map(value =>
          zio.aws.ec2.model.ClientVpnConnectionStatusCode.wrap(value)
        )
    override val message: Option[String] =
      scala.Option(impl.message()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ClientVpnConnectionStatus
  ): zio.aws.ec2.model.ClientVpnConnectionStatus.ReadOnly = new Wrapper(impl)
}
